clear all; close all; clc

% scaling parameter
alpha = 1;

% reaction rate constant parameter
D = @(N) N^(-1-alpha);

% time scaling
%tau = @(N,T) T;
%tau = @(N,T) N*T;
tau = @(N,T) N^(1+alpha)*T;

% initial displacement parameter
epsilon = 2;

% time limit
T = 5;

% scaling parameters vector
Nvec = 2.^(4:2:10);

% show figure
figure

for i = 1:length(Nvec)
    
    % scaling parameter
    N = Nvec(i);
    
    % set seed
    rng default
    
    % initial state
    X0 = epsilon*N*ones(2,1);
    
    % process simulation
    [t,X] = TogashiKaneko(2,D(N),N,X0,tau(N,T),Inf);
    
    % normalized countings
    Y = X/N;
    
    % sum process
    W = sum(Y);
    
    % normalized time
    t = t/tau(N,1);
    
	% deterministic trajectory
    Wdet = 2 + 2*(epsilon-1)*exp(-t);
    
    % plot stochastic processes
    subplot(2,2,i)
    stairs(t,Y(1,:)), hold on
    stairs(t,Y(2,:)), hold on
    
    % plot sum
    stairs(t,W), hold on

    % plot deterministic process
    %plot(t,Wdet,'k--')
    
    % plot equilibrium points
    %plot(t([1 end]),[epsilon;epsilon],'k--')
    %plot(t([1 end]),2*[epsilon;epsilon],'k--')

    % graphic options
    xlim([0 T]), ylim([0,5])
    xlabel('\tau'), ylabel('C(\tau)')
    str = sprintf('Process realization: N = %d',N);
    title(str)
    
end
